package com.starbuds.robotanchor.controller;

import com.starbuds.robotanchor.constant.ResponseCode;
import com.starbuds.robotanchor.job.StartStopLiveJob;
import com.starbuds.robotanchor.service.RobotService;
import com.starbuds.server.common.constant.common.GlobalApiError;
import com.starbuds.server.common.pojo.api.Result;
import org.apache.commons.lang3.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.io.IOException;

/**
 * 机器人控制
 *
 * @author aoe
 * @date 2020/6/12
 */
@RestController
public class RobotController {

    @Resource
    private RobotService robotService;

    @Resource
    private StartStopLiveJob startStopLiveJob;

    /**
     * 开播
     *
     * @param phone
     * @param categoryId
     * @return
     * @throws IOException
     */
    @GetMapping("startLive")
    public Result startLive(String phone, Long categoryId) throws IOException {
        if (StringUtils.isBlank(phone) || categoryId == null) {
            return new Result(GlobalApiError.BadRequest, "phone or categoryId is null");
        }
        String result = robotService.startLive(phone, categoryId);
        if (ResponseCode.SUCCESS.equals(result)) {
            return new Result(result);
        }

        return new Result(GlobalApiError.OperationFailed, result);
    }

    @GetMapping("stopLive")
    public Result stopLive(String phone) throws IOException {
        if (StringUtils.isBlank(phone)) {
            return new Result(GlobalApiError.BadRequest, "phone is not null");
        }

        String result = robotService.stopLive(phone);
        if (ResponseCode.SUCCESS.equals(result)) {
            return new Result(result);
        }

        return new Result(GlobalApiError.OperationFailed, result);
    }

    @GetMapping("startAll")
    public Result startAll() {
        startStopLiveJob.startLive();
        return new Result("OK");
    }

    @GetMapping("stopAll")
    public Result stopAll() {
        startStopLiveJob.stopLive();
        return new Result("OK");
    }
}
