package com.starbuds.robotanchor.job;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import com.starbuds.robotanchor.bean.Anchor;
import com.starbuds.robotanchor.constant.ResponseCode;
import com.starbuds.robotanchor.service.RobotService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;

/**
 * 开播停播任务
 *
 * @author aoe
 * @date 2020/6/17
 */
@Component
@Slf4j
public class StartStopLiveJob {

    @Resource
    private RobotService robotService;

    /**
     * 开播
     *
     * @return
     */
//    @Scheduled(cron = "0 3 0 * * ?")
    public void startLive() {
        log.info("开播定时任务" + DateUtil.now());
        List<Anchor> anchorList = robotService.getAnchorList();
        for (Anchor anchor : anchorList) {
            String phone = anchor.getPhone();
            try {
                String result = robotService.startLive(phone, 14L);
                if (ResponseCode.SUCCESS.equals(result)) {
                    log.info("定时任务-开播成功！phone={}", phone);
                } else {
                    log.warn("定时任务-开播失败！phone={} result={}", phone, result);
                }
            } catch (IOException e) {
                log.error(StrUtil.format("定时任务开播失败！phone={}", phone), e);
            }
        }
    }

    /**
     * 停播
     *
     * @return
     */
//    @Scheduled(cron = "0 30 9 * * ?")
    public void stopLive() {
        log.info("停播定时任务" + DateUtil.now());
        List<Anchor> anchorList = robotService.getAnchorList();
        for (Anchor anchor : anchorList) {
            String phone = anchor.getPhone();
            try {
                String result = robotService.stopLive(phone);
                if (ResponseCode.SUCCESS.equals(result)) {
                    log.info("定时任务-停播成功！phone={}", phone);
                } else {
                    log.warn("定时任务-停播失败！phone={} result={}", phone, result);
                }
            } catch (IOException e) {
                log.error(StrUtil.format("定时任务-停播失败！phone={}", phone), e);
            }
        }
    }

}
