package com.starbuds.robotanchor.service;

import com.alibaba.fastjson.JSONObject;
import com.starbuds.robotanchor.utils.FileTools;
import com.starbuds.robotanchor.utils.XyHttpTools;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.Arrays;
import java.util.HashMap;
import java.util.Map;

/**
 * 登录测试
 *
 * @author aoe
 * @date 2020/5/15
 */
@Slf4j
@Service
public class AppLoginService {

    public void saveLoginToken(String host, String phone) throws IOException {
        String token = login(host, phone);

        log.info("TOKEN = " + token);
        FileTools.writeToFile(FileTools.getTestResourcesFilePath("Login-TOKEN.txt"), Arrays.asList(token));
    }

    private String login(String host, String phone) throws IOException {
        getInitConfig(host);
        String smsCode = sendSmsCode(host, phone);
        String token = loginBySmsCode(host, phone, smsCode);
        return token;
    }

    public String sendSmsCode(String host, String phone) throws IOException {
        Map<String, String> params = new HashMap<>();
        params.put("phone", phone);
        params.put("codeType", "101");
        params.put("countryId", "86");
        String res = XyHttpTools.post(getApiCommonHost(host), "api-common/v1/login/sendSmsCode", params);
        return JSONObject.parseObject(res).getJSONObject("data").getString("code");
    }

    public String loginBySmsCode(String host, String phone, String smsCode) throws IOException {
        Map<String, String> params = new HashMap<>();
        params.put("phone", phone);
        params.put("code", smsCode);
        params.put("countryId", "86");
        String res = XyHttpTools.post(getApiCommonHost(host), "api-common/v1/login/bySmsCode", params);
        return JSONObject.parseObject(res).getJSONObject("data").getString("token");
    }

    private static String getApiCommonHost(String host) {
        return host.replace("7152", "7151");
    }

    /**
     * 获取初始化配置
     *
     * @throws IOException
     */
    private static void getInitConfig(String host) throws IOException {
        String res = XyHttpTools.get(host, "api-app/v1/config/getInitConfig");
        log.info("getInitConfig结果\n{}", res);
    }

}
