package com.starbuds.robotanchor.service;

import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.starbuds.robotanchor.bean.Anchor;
import com.starbuds.robotanchor.constant.ResponseCode;
import com.starbuds.robotanchor.constant.RobotDB;
import com.starbuds.robotanchor.mapper.RobotDAO;
import com.starbuds.robotanchor.pojo.db.RobotDO;
import com.starbuds.robotanchor.utils.XyHttpTools;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.*;
import java.util.concurrent.atomic.AtomicReference;

import static com.starbuds.robotanchor.utils.SpringContextUtil.isDev;
import static com.starbuds.robotanchor.utils.XyResultTools.getData;

/**
 * 机器人服务
 *
 * @author aoe
 * @date 2020/6/12
 */
@Slf4j
@Service
public class RobotService {

    @Value("${xy.host}")
    private String HOST;

    @Resource
    private AppLoginService appLoginService;

    @Resource
    private RobotDAO robotDAO;

    /**
     * 开播
     *
     * @param phone
     * @param categoryId
     * @return
     * @throws IOException
     */
    public String startLive(String phone, Long categoryId) throws IOException {
        appLoginService.saveLoginToken(HOST, phone);

        // 推流
        String action = "api-app/v1/live/startLive";

        Map<String, String> params = new HashMap<>();
        params.put("liveTitle", "欢迎来到我的直播间");
        params.put("categoryId", categoryId.toString());
        String res = XyHttpTools.post(HOST, action, params);
        log.info("推流信息 {}", res);

        JSONObject data = getData(res);
        String pushUrl = data.getString("pushUrl");
        String liveHisId = data.getString("liveHisId");
        if (StringUtils.isBlank(pushUrl) || StringUtils.isBlank(liveHisId)) {
            return StrUtil.format("推流信息获取失败 pushUrl={} liveHisId={}", pushUrl, liveHisId);
        }

        RobotDO robot = new RobotDO();
        robot.setPhone(phone);
        robot.setLiveHisId(liveHisId);
        robot.setIsLive(RobotDB.IS_LIVE_YES);

        robotDAO.insertOrUpdate(robot);

        String video = StrUtil.format("/home/xy/video/{}.ts", phone);
        String command = StrUtil.format("nohup /usr/local/ffmpeg/bin/ffmpeg -re -stream_loop -1 -i {} -acodec copy -vcodec copy -f flv \"{}\"", video, pushUrl);

        log.info("推流命令\n{}", command);

        String commandShell = StrUtil.format(" {} \"{}\"", video, pushUrl);
        log.info("commandShell\n\n{}", commandShell);

        String[] cmd = {"sh", "/home/xy/shell-script/push_video.sh", video, pushUrl};
        boolean flag = executeShell(cmd);
        if (flag) {
            return ResponseCode.SUCCESS;
        }
        return "执行推送脚本失败";
    }

    /**
     * 关闭直播
     *
     * @param phone
     * @return
     * @throws IOException
     */
    public String stopLive(String phone) throws IOException {
        RobotDO robot = robotDAO.selectByPrimaryKey(phone);
        if (robot == null) {
            return "机器人信息不存在";
        }
        String liveHisId = robot.getLiveHisId();
        if (StringUtils.isBlank(liveHisId) || RobotDB.LIVE_HIS_ID_EMPTY.equals(liveHisId)) {
            return "直播Id为空，不能关闭";
        }
        return stopLive(liveHisId, phone);
    }

    /**
     * 获得全部主播列表
     *
     * @return
     */
    public List<Anchor> getAnchorList() {
        if (isDev()) {
            return initDev();
        }
        return initPro();
    }

    private String stopLive(String liveHisId, String phone) throws IOException {
        // stop streaming
        String[] cmd = {"sh", "/home/xy/shell-script/close_stream.sh", phone};
        boolean shellFlag = executeShell(cmd);

        appLoginService.saveLoginToken(HOST, phone);
        String action = "api-app/v1/live/stopLive";
        Map<String, String> params = new HashMap<>();
        params.put("liveHisId", liveHisId);
        String res = XyHttpTools.post(HOST, action, params);
        log.info("关闭推流结果\n{}", res);

        RobotDO robot = new RobotDO();
        robot.setPhone(phone);
        robot.setIsLive(RobotDB.IS_LIVE_NO);
        int updateCount = robotDAO.update(robot);
        log.info("更新直播状态为关闭 updateCount={}", updateCount);

        if (shellFlag) {
            return ResponseCode.SUCCESS;
        }

        return StrUtil.format("关闭直播失败！关闭脚本执行结果={}");
    }

    private boolean executeShell(String... cmd) {
        AtomicReference<Boolean> flag = new AtomicReference<>(true);
        Thread thread = new Thread(() -> {
            try {
                Runtime.getRuntime().exec(cmd);
            } catch (IOException e) {
                log.error(StrUtil.format("执行Shell失败 {}", Arrays.toString(cmd)), e);
                flag.set(false);
            }
        });
        thread.setDaemon(false);
        thread.start();

        return flag.get();
    }

    private List<Anchor> initPro() {
        List<Anchor> anchorList = new ArrayList<>();
        anchorList.add(new Anchor("99905710036", "http://user.qn.paqukeji.com/avatar/141095522533376/1591976493142.png"));
        anchorList.add(new Anchor("99905710034", "http://user.qn.paqukeji.com/avatar/141097368027137/1591976400465.png"));
        anchorList.add(new Anchor("99905710032", "http://user.qn.paqukeji.com/avatar/141094792724480/1591976234405.png"));
        anchorList.add(new Anchor("99905710018", "http://user.qn.paqukeji.com/avatar/141093106614272/1591951963036.png"));
        anchorList.add(new Anchor("99905710017", "http://user.qn.paqukeji.com/avatar/140389889605632/1591866188988.png"));
        anchorList.add(new Anchor("99905710011", "http://user.qn.paqukeji.com/avatar/140401381998593/1591866946690.png"));
        anchorList.add(new Anchor("99905710010", "http://user.qn.paqukeji.com/avatar/140400987734016/1591866815236.png"));
        anchorList.add(new Anchor("99905710008", "http://user.qn.paqukeji.com/avatar/140396894093313/1591866399469.png"));
        return anchorList;
    }

    private List<Anchor> initDev() {
        List<Anchor> anchorList = new ArrayList<>();
        anchorList.add(new Anchor("15757876459", "http://user.qn.paqukeji.com/avatar/141095522533376/1591976493142.png"));
        anchorList.add(new Anchor("15757873652", "http://user.qn.paqukeji.com/avatar/141097368027137/1591976400465.png"));
        anchorList.add(new Anchor("15757873399", "http://user.qn.paqukeji.com/avatar/141094792724480/1591976234405.png"));
        anchorList.add(new Anchor("15267114919", "http://user.qn.paqukeji.com/avatar/141093106614272/1591951963036.png"));
        anchorList.add(new Anchor("16979898979", "http://user.qn.paqukeji.com/avatar/140389889605632/1591866188988.png"));
        anchorList.add(new Anchor("19913300000", "http://user.qn.paqukeji.com/avatar/140401381998593/1591866946690.png"));
        anchorList.add(new Anchor("15267114811", "http://user.qn.paqukeji.com/avatar/140400987734016/1591866815236.png"));
        anchorList.add(new Anchor("15757873366", "http://user.qn.paqukeji.com/avatar/140396894093313/1591866399469.png"));
        return anchorList;
    }
}
