package com.starbuds.robotanchor.utils;

import com.starbuds.server.common.constant.common.AppEnv;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

import java.util.Locale;

/**
 * 备注
 *
 * @author Lay
 * @date 2019/12/17
 */
@Component
public class SpringContextUtil {
    private static ApplicationContext context = null;

    public static void setApplicationContext(ApplicationContext applicationContext)
            throws BeansException {
        context = applicationContext;
    }

    /**
     * 获取 Bean
     *
     * @param beanName
     * @param <T>
     * @return
     */
    public static <T> T getBean(String beanName) {
        return (T) context.getBean(beanName);
    }


    /**
     * 国际化
     *
     * @param key
     * @return
     */
    public static String getMessage(String key) {
        return context.getMessage(key, null, Locale.getDefault());
    }


    /**
     * 获取当前环境
     *
     * @return
     */
    public static String getActiveProfile() {
        String[] profiles = context.getEnvironment().getActiveProfiles();
        if (profiles == null || profiles.length < 1) {
            return "undefine";
        }
        return profiles[0];
    }

    public static boolean isDev() {
        return !AppEnv.PROD.equalsIgnoreCase(getActiveProfile());
    }
}
