package com.starbuds.robotanchor.utils;

import cn.hutool.core.codec.Base64;
import cn.hutool.crypto.SecureUtil;
import com.alibaba.fastjson.JSON;
import com.starbuds.server.common.constant.common.AppType;
import com.starbuds.server.common.constant.common.ClientType;
import com.starbuds.server.common.constant.common.SignType;
import com.starbuds.server.common.pojo.api.HeaderPackage;
import lombok.extern.slf4j.Slf4j;
import org.springframework.util.CollectionUtils;

import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Http请求工具
 *
 * @author aoe
 * @date 2020/5/13
 */
@Slf4j
public class XyHttpTools {

    public static final String HOST_DEV = "http://127.0.0.1:7152/";
    public static final String HOST_API_COMMON_DEV = "http://127.0.0.1:7151/";
    public static final String HOST_TEST_ALY = "http://api.starbuds.laylib.com/";

    // 渠道
    public static final String HOST_CHANNEL_DEV = "http://127.0.0.1:7157/";
    public static final String HOST_CHANNEL_TEST_ALY = "http://ch.starbuds.laylib.com/";

    // 包类型 AppPkg AdminPkg
    public final static String PKG_TYPE_APP = "AppPkg";
    public final static String PKG_TYPE_ADMIN = "AdminPkg";
    public static String pkgType = PKG_TYPE_APP;


    public static String get(String host, String action) throws IOException {
        String pkg = getPkg();

        Map<String, String> headers = new HashMap<>();
        headers.put("pkg", pkg);
        headers.put("Type", "application%2Fx-www-form-urlencoded%3B%20charset%3Dutf-8");

        String url = host + action;
        String res = OkHttpTools.get(url, headers);
        log.info("\n\n GET {} \n RESULT \n\n {} \n", url, res);
        return res;
    }

    public static String post(String host, String action, Map<String, String> params) throws IOException {
        Map<String, String> headers = new HashMap<>();
        headers.put("pkg", getPkg());
        headers.put("Type", "application%2Fx-www-form-urlencoded%3B%20charset%3Dutf-8");

        String url = host + action;
        String res = OkHttpTools.post(url, params, headers);
        log.info("\n\n POST {} \n RESULT \n\n {} \n", url, res);
        return res;
    }


    private static String getAppPkg(String token) {
        // App head pkg
        HeaderPackage headerPackage = new HeaderPackage();
        headerPackage.setClientType(ClientType.Android);
        headerPackage.setAppType(AppType.App);
        headerPackage.setPackageName("com.starbuds.app");
        headerPackage.setTimestamp(System.currentTimeMillis());
        headerPackage.setDeviceId("deviceId");
        headerPackage.setToken(token);
        headerPackage.setAppVersion("1.0.0");
        headerPackage.setChannelId(135120971366400L);
        headerPackage.setSignType(SignType.MD5);
        String toSign = headerPackage.toQueryString();
        toSign = String.format("%s%s.%s.security", toSign, headerPackage.getPackageName(), headerPackage.getClientType().getName());
        headerPackage.setSign(SecureUtil.md5(toSign));
        String headerJson = JSON.toJSONString(headerPackage);
        return Base64.encode(headerJson);
    }

    public static String getAdminPkg(String token) {
        // Admin head pkg
        HeaderPackage headerPackage = new HeaderPackage();
        headerPackage.setClientType(ClientType.Web);
        headerPackage.setAppType(AppType.Admin);
        headerPackage.setPackageName("com.starbuds.manage");
        headerPackage.setTimestamp(System.currentTimeMillis());
        headerPackage.setDeviceId("deviceId");
        headerPackage.setToken(token);
        headerPackage.setAppVersion("1.0.0");
        headerPackage.setSignType(SignType.MD5);
        String toSign = headerPackage.toQueryString();
        headerPackage.setSign(SecureUtil.md5(toSign + "pq" + SignType.MD5));
        String headerJson = JSON.toJSONString(headerPackage);
        return Base64.encode(headerJson);
    }

    private static String getPkg() {
        String token = getLoginToken();
        return PKG_TYPE_ADMIN.equals(pkgType) ? getAdminPkg(token) : getAppPkg(token);
    }

    private static String getLoginToken() {
        List<String> tokenList = FileTools.readList(FileTools.getTestResourcesFilePath("Login-TOKEN.txt"));
        if (CollectionUtils.isEmpty(tokenList)) {
            return "";
        }
        return tokenList.get(0);
    }
}
